--- a/res/res_pjsip_session.c	2019-01-25 14:37:55.231995027 +0100
+++ b/res/res_pjsip_session.c	2019-01-25 17:06:11.713010417 +0100
@@ -2485,10 +2485,24 @@
 {
 	struct ast_sip_session_supplement *supplement;
 	struct pjsip_status_line status = rdata->msg_info.msg->line.status;
+	pjsip_rdata_sdp_info *sdp_info;
 
 	ast_debug(3, "Response is %d %.*s\n", status.code, (int) pj_strlen(&status.reason),
 			pj_strbuf(&status.reason));
 
+	/* Michael: handle 183 Session Progress if there is no MEDIA in package as 180 Ringing */
+	if (status.code == 183 && (! (sdp_info = pjsip_rdata_get_sdp_info(rdata)) || sdp_info->sdp_err != PJ_SUCCESS || ! sdp_info->sdp)) {
+		ast_debug(3, "Handle response %d %.*s as 180 Session Progress because it contains no SDP\n", status.code, (int) pj_strlen(&status.reason),
+				pj_strbuf(&status.reason));
+		rdata->msg_info.msg->line.status.code = 180;
+	}
+	/* Michael: handle 180 Ringing like 183 if it contains media */
+	else if (status.code == 180 && ((sdp_info = pjsip_rdata_get_sdp_info(rdata)) && sdp_info->sdp_err == PJ_SUCCESS && sdp_info->sdp)) {
+		ast_debug(3, "Handle response %d %.*s as 183 Session Progress because it contains SDP\n", status.code, (int) pj_strlen(&status.reason),
+				pj_strbuf(&status.reason));
+		rdata->msg_info.msg->line.status.code = 183;
+	}
+
 	AST_LIST_TRAVERSE(&session->supplements, supplement, next) {
 		if (!(supplement->response_priority & response_priority)) {
 			continue;
